<map version="0.9.0">
<!-- To view this file, download free mind mapping software FreeMind from http://freemind.sourceforge.net -->
<node COLOR="#ffffff" CREATED="1338981655812" ID="ID_1037924826" MODIFIED="1349124476292" TEXT="sc todo">
<node CREATED="1342207998922" ID="ID_1911668657" MODIFIED="1342208001400" POSITION="left" TEXT="ongoing">
<node CREATED="1341492697516" ID="ID_1679039133" MODIFIED="1341492709337" TEXT="maintain and moderate google groups page">
<node COLOR="#ff0000" CREATED="1342204875063" ID="ID_1492626014" MODIFIED="1342208946894" TEXT="answer messages at least twice daily Mon-Fri">
<font BOLD="true" NAME="Dialog" SIZE="12"/>
</node>
</node>
</node>
<node CREATED="1342208221429" ID="ID_1196736768" MODIFIED="1342208223449" POSITION="left" TEXT="july">
<node COLOR="#ffff00" CREATED="1342212410196" ID="ID_1280861564" MODIFIED="1343750118902" TEXT="prepare 1-page PDF for licence marketing purposes">
<node COLOR="#ffff00" CREATED="1343234832464" ID="ID_1164735646" MODIFIED="1343750118957" TEXT="A3 poster with graphics"/>
</node>
<node COLOR="#ffff00" CREATED="1341491446242" ID="ID_1854253075" MODIFIED="1344506682854" TEXT="compositions">
<node COLOR="#ffff00" CREATED="1342207919083" ID="ID_343686650" MODIFIED="1343996942222" TEXT="document and extend if necessary the Reich-like piece from the workshops examples">
<node COLOR="#ffff00" CREATED="1342207956787" ID="ID_37718502" MODIFIED="1343996942206" TEXT="render sample-based mp3"/>
</node>
<node COLOR="#ffff00" CREATED="1342207712692" ID="ID_162111501" MODIFIED="1344346026193" TEXT="A Lindenmayer piece">
<node COLOR="#ffff00" CREATED="1342209069011" ID="ID_1355345227" MODIFIED="1344346026207" TEXT="including more focus on clm-play">
<node COLOR="#ffff00" CREATED="1342209085705" ID="ID_321105726" MODIFIED="1344346026207" TEXT="great-sounding sound files"/>
</node>
</node>
<node COLOR="#ffff00" CREATED="1342219033891" ID="ID_1190820477" MODIFIED="1344352497101" TEXT="add manual compositions to music.html"/>
</node>
<node CREATED="1338981675440" ID="ID_731366231" MODIFIED="1341491350934" TEXT="robodoc">
<node COLOR="#ffffff" CREATED="1341491350956" ID="ID_56038962" MODIFIED="1349347049017" TEXT="address straggling methods">
<node COLOR="#ffff00" CREATED="1341491367401" ID="ID_1671880737" MODIFIED="1344428189392" TEXT="add robodoc and uts for them"/>
<node COLOR="#ffffff" CREATED="1341492876804" ID="ID_1696898039" MODIFIED="1349365007529" TEXT="they are:">
<node COLOR="#ffff00" CREATED="1341495852418" ID="ID_71645476" MODIFIED="1344353480541" TEXT="event/has-mark-before"/>
<node COLOR="#ffff00" CREATED="1341497411990" ID="ID_477023107" MODIFIED="1344356567580" TEXT="pitch-seq/+pitch-seq-lowest-equals-prefers-high+"/>
<node COLOR="#ffff00" CREATED="1341497419211" ID="ID_604888435" MODIFIED="1344356571066" TEXT="pitch-seq/ +pitch-seq-lowest-equals-prefers-low+"/>
<node COLOR="#ffff00" CREATED="1341497727448" ID="ID_1880628840" MODIFIED="1344358615854" TEXT="pitch/no-accidental"/>
<node COLOR="#ffff00" CREATED="1341498254087" ID="ID_752648896" MODIFIED="1344420705153" TEXT="player/total-degrees"/>
<node COLOR="#ffff00" CREATED="1341498263466" ID="ID_806002845" MODIFIED="1344421070086" TEXT="player/total-bars"/>
<node COLOR="#ffff00" CREATED="1341498276730" ID="ID_209373621" MODIFIED="1344421415154" TEXT="player/tessitura-note"/>
<node COLOR="#ffff00" CREATED="1341501731812" ID="ID_1322040728" MODIFIED="1344422084475" TEXT="rthm-seq/delete-marks"/>
<node COLOR="#ffff00" CREATED="1343122661088" ID="ID_273183557" MODIFIED="1344422499060" TEXT="rthm-seq::get-first"/>
<node COLOR="#ffff00" CREATED="1343122682380" ID="ID_671824703" MODIFIED="1344422732108" TEXT="rthm-seq::get-last"/>
<node COLOR="#ffff00" CREATED="1342613727791" ID="ID_1084943657" MODIFIED="1344428194491" TEXT="rsb/set-amplitudes"/>
<node COLOR="#ffff00" CREATED="1342613730424" ID="ID_139554386" MODIFIED="1344423644345" TEXT="rsb/set-dynamics"/>
<node COLOR="#ffff00" CREATED="1341503226689" ID="ID_1552132219" MODIFIED="1344427178735" TEXT="slippery-chicken-edit/add-tuplet-bracket-to-bar"/>
<node COLOR="#ffff00" CREATED="1341503234873" ID="ID_1014339063" MODIFIED="1344428178764" TEXT="slippery-chicken-edit/add-tuplet-brackets-to-beats"/>
<node COLOR="#ffff00" CREATED="1345120433188" ID="ID_1405698082" MODIFIED="1349365379301">
<richcontent TYPE="NODE"><html>
  <head>
    
  </head>
  <body>
    <h2 class="summary searchable">
      chord::add-pitches
    </h2>
  </body>
</html></richcontent>
<node COLOR="#ffffff" CREATED="1345120469136" ID="ID_1282075428" MODIFIED="1349124387740" TEXT="test with written pitches too (transposing)">
<node COLOR="#ff0000" CREATED="1349365362899" ID="ID_407503547" MODIFIED="1349365373931" TEXT="see node below!"/>
</node>
</node>
<node COLOR="#ffff00" CREATED="1345120439360" ID="ID_57648940" MODIFIED="1349365382875" TEXT="chord::rm-pitches">
<node COLOR="#ffffff" CREATED="1345120469136" ID="ID_607710873" MODIFIED="1349124387737" TEXT="test with written pitches too (transposing)">
<node COLOR="#ff0000" CREATED="1349365362899" ID="ID_740246606" MODIFIED="1349365373931" TEXT="see node below!"/>
</node>
</node>
<node COLOR="#ffff00" CREATED="1345120448784" ID="ID_129244262" MODIFIED="1349367025710" TEXT="sc::add-pitches-to-chord">
<node COLOR="#ffff00" CREATED="1345120469136" ID="ID_430531306" MODIFIED="1349367032009" TEXT="test with written pitches too (transposing)"/>
</node>
<node COLOR="#ffff00" CREATED="1345120457359" ID="ID_1196294673" MODIFIED="1349441792365" TEXT="sc::rm-pitches-from-chord">
<node COLOR="#ffff00" CREATED="1345120469136" ID="ID_761671887" MODIFIED="1349441796153" TEXT="test with written pitches too (transposing)"/>
</node>
<node COLOR="#ff0000" CREATED="1349365059298" ID="ID_1203075547" MODIFIED="1349365143545" TEXT="REGARDING CHORD::ADD-PITCHES WRITTEN PITCHES">
<node COLOR="#ff0000" CREATED="1349365081828" ID="ID_661360842" MODIFIED="1349365143545" TEXT="there are currently no chord-capable transposing instruments">
<node COLOR="#ff0000" CREATED="1349365109538" ID="ID_1470240537" MODIFIED="1349365143545" TEXT="other than guitar, which is octave transposition">
<node COLOR="#ff0000" CREATED="1349367046017" ID="ID_1967781300" MODIFIED="1349367061201" TEXT="i&apos;ve written a ut using guitar"/>
</node>
</node>
<node COLOR="#ff0000" CREATED="1349365149736" ID="ID_1548939805" MODIFIED="1349365206922" TEXT="testing written pitches with just the event (chord object) doesn&apos;t work">
<node COLOR="#ff0000" CREATED="1349365171989" ID="ID_725873931" MODIFIED="1349365206922" TEXT="each slot pitches-or-chord, written-pitches-or-chord are separate objects">
<node COLOR="#ff0000" CREATED="1349365192206" ID="ID_1268949445" MODIFIED="1349365206922" TEXT="changing one doesn&apos;t automatically update the other"/>
</node>
</node>
</node>
</node>
</node>
<node COLOR="#00ff00" CREATED="1341491539339" ID="ID_1003523238" MODIFIED="1341506281582" TEXT="spell-check all robodoc"/>
</node>
<node COLOR="#ffff00" CREATED="1341491379972" ID="ID_163727854" MODIFIED="1344513218763" TEXT="test-suite">
<node COLOR="#00ff00" CREATED="1341491714711" ID="ID_1008395423" MODIFIED="1342183677341" TEXT="add remaining u.g. examples to test-suite"/>
<node COLOR="#ffff00" CREATED="1341491836072" ID="ID_971579877" MODIFIED="1344513214792" TEXT="add lots of auto-slur calls to pieces as extra tests"/>
</node>
<node COLOR="#00ff00" CREATED="1338981682312" ID="ID_1247182732" MODIFIED="1342184174780" TEXT="workshops">
<node COLOR="#00ff00" CREATED="1338981694871" ID="ID_60776274" MODIFIED="1341491520777" TEXT="slides"/>
<node COLOR="#00ff00" CREATED="1341491401984" ID="ID_637280240" MODIFIED="1341491526000" TEXT="example code"/>
<node COLOR="#00ff00" CREATED="1341491410293" ID="ID_244602002" MODIFIED="1341491526000" TEXT="exercises"/>
</node>
</node>
<node COLOR="#ffffff" CREATED="1342208223800" ID="ID_1143605291" MODIFIED="1349124471668" POSITION="left" TEXT="august">
<node COLOR="#ffffff" CREATED="1341491446242" ID="ID_1516798740" MODIFIED="1349124418266" TEXT="compositions">
<node COLOR="#ffffff" CREATED="1342208592638" ID="ID_1372328781" MODIFIED="1349124418267" TEXT="a tonal piece">
<node COLOR="#ffff00" CREATED="1344881640564" ID="ID_322113754" MODIFIED="1349875113975" TEXT="features to include">
<node COLOR="#ffff00" CREATED="1342209124449" ID="ID_1603651400" MODIFIED="1349124434475" TEXT="not minimalist"/>
<node COLOR="#ffff00" CREATED="1342209135267" ID="ID_965682835" MODIFIED="1349124434475" TEXT="using functional tonal harmony"/>
<node COLOR="#ffff00" CREATED="1342209147029" ID="ID_362267889" MODIFIED="1349124434475" TEXT="in a key other than C"/>
<node COLOR="#ffff00" CREATED="1342209155317" ID="ID_1288451892" MODIFIED="1349124434475" TEXT="with modulations"/>
</node>
<node COLOR="#ffff00" CREATED="1345120271668" ID="ID_844458936" MODIFIED="1349124428249" TEXT="volkhardt&apos;s tonal improv patterns">
<node COLOR="#ffff00" CREATED="1347016706461" ID="ID_1267371714" MODIFIED="1349124428249" TEXT="accompanying manual page"/>
</node>
<node COLOR="#ffff00" CREATED="1344708501005" ID="ID_1950025798" MODIFIED="1344881627346" TEXT="bach chorale">
<node COLOR="#ff0000" CREATED="1344708540455" ID="ID_77963701" MODIFIED="1349449204308" TEXT="accompanying manual page">
<node COLOR="#ff0000" CREATED="1349449173749" ID="ID_1618001617" MODIFIED="1349449204308" TEXT="does MDE still want this?"/>
</node>
<node COLOR="#ffffff" CREATED="1345120254587" ID="ID_608779469" MODIFIED="1349124405507" TEXT="fix enharmonic spellings"/>
</node>
<node COLOR="#ffff00" CREATED="1344708510572" ID="ID_638845022" MODIFIED="1344881631839" TEXT="beethoven cavatina">
<node COLOR="#ff0000" CREATED="1344708554070" ID="ID_534489226" MODIFIED="1349449204308" TEXT="accompanying manual page">
<node COLOR="#ff0000" CREATED="1349449188767" ID="ID_1979569458" MODIFIED="1349449204308" TEXT="does MDE still want this?"/>
</node>
</node>
</node>
<node COLOR="#00ff00" CREATED="1345120213438" ID="ID_843580640" MODIFIED="1350045785113" TEXT="fix nouveau-reich heap-exhaustion">
<node COLOR="#00ff00" CREATED="1346840710735" ID="ID_810810805" MODIFIED="1350045785114" TEXT="make a note in the lisp file about sbcl maybe screwing up every 3rd or 4th time"/>
</node>
</node>
<node COLOR="#ffffff" CREATED="1342208040192" ID="ID_1904656957" MODIFIED="1349124471668" TEXT="videos">
<node COLOR="#00ff00" CREATED="1342208042144" ID="ID_1788398274" MODIFIED="1346840868050" TEXT="demonstrating sc in action"/>
<node COLOR="#00ff00" CREATED="1342208060849" ID="ID_614170223" MODIFIED="1346840868051" TEXT="with verbal overview"/>
<node COLOR="#00ff00" CREATED="1342208081258" ID="ID_1319170415" MODIFIED="1349875151827" TEXT="needs storyboarding and planning">
<node COLOR="#00ff00" CREATED="1343138812859" ID="ID_1365703101" MODIFIED="1346840877516" TEXT="using workshop slides">
<node COLOR="#00ff00" CREATED="1343138826027" ID="ID_1805963491" MODIFIED="1346840877517" TEXT="extract most salient points"/>
</node>
<node COLOR="#00ff00" CREATED="1343138799892" ID="ID_876696512" MODIFIED="1346840877516" TEXT="starting up slippery chicken"/>
<node COLOR="#00ff00" CREATED="1343138643295" ID="ID_613763251" MODIFIED="1346840877516" TEXT="overview">
<node COLOR="#00ff00" CREATED="1343138706160" ID="ID_411398260" MODIFIED="1346840877516" TEXT="coreUsage">
<node COLOR="#00ff00" CREATED="1343138713991" ID="ID_659620648" MODIFIED="1346840877516" TEXT="including output"/>
</node>
</node>
</node>
<node COLOR="#ffffff" CREATED="1342208091863" ID="ID_1615681583" MODIFIED="1349124451902" TEXT="post on youtube and vimeo"/>
<node COLOR="#ffff00" CREATED="1344859408126" ID="ID_286503481" MODIFIED="1356232255095" TEXT="multiple short clips at 60-90 seconds">
<node COLOR="#ffff00" CREATED="1344865413965" ID="ID_1413822213" MODIFIED="1347024434412" TEXT="01 - Introduction"/>
<node COLOR="#ffff00" CREATED="1344865433963" ID="ID_800229671" MODIFIED="1347024434412" TEXT="02 - Starting up and loading"/>
<node COLOR="#ffff00" CREATED="1344865538241" FOLDED="true" ID="ID_1916417406" MODIFIED="1349124602904" TEXT="03 - Mini">
<node COLOR="#ffff00" CREATED="1344865628572" ID="ID_919745727" MODIFIED="1347799311330" TEXT="Call to make-slippery-chicken"/>
<node COLOR="#ffff00" CREATED="1344865679792" ID="ID_1297070434" MODIFIED="1347799311330" TEXT="ensemble"/>
<node COLOR="#ffff00" CREATED="1344865685080" ID="ID_1181656998" MODIFIED="1347799311329" TEXT="set-palette"/>
<node COLOR="#ffff00" CREATED="1344865688904" ID="ID_1164727403" MODIFIED="1347799311329" TEXT="set-map"/>
<node COLOR="#ffff00" CREATED="1344865691631" ID="ID_1031612030" MODIFIED="1347799311329" TEXT="rthm-seq-palette"/>
<node COLOR="#ffff00" CREATED="1344865699031" ID="ID_1678143717" MODIFIED="1347799311329" TEXT="rthm-seq-map"/>
<node COLOR="#ffff00" CREATED="1344865702895" ID="ID_843607359" MODIFIED="1347799311329" TEXT="midi-play"/>
<node COLOR="#ffff00" CREATED="1344865706200" ID="ID_1669272613" MODIFIED="1347799311329" TEXT="cmn-display"/>
<node COLOR="#ffff00" CREATED="1344865709855" ID="ID_183833990" MODIFIED="1347799311329" TEXT="write-lp-data-for-all"/>
</node>
<node COLOR="#ffff00" CREATED="1344865795282" FOLDED="true" ID="ID_1305550908" MODIFIED="1349124603895" TEXT="04 - Note-names and scales">
<node COLOR="#ffff00" CREATED="1344865833621" ID="ID_1654380558" MODIFIED="1347799318477" TEXT="Pitches">
<node COLOR="#ffff00" CREATED="1344865875968" ID="ID_1836778347" MODIFIED="1347799318477" TEXT="chromatic/qt/12-tone"/>
</node>
<node COLOR="#ffff00" CREATED="1344866073613" ID="ID_360897426" MODIFIED="1347799318476" TEXT="Scales"/>
</node>
<node COLOR="#ffff00" CREATED="1345137380656" FOLDED="true" ID="ID_1709997272" MODIFIED="1349124604661" TEXT="05 - Rhythms">
<node COLOR="#ffff00" CREATED="1344865938744" ID="ID_1486122635" MODIFIED="1347799323533" TEXT="durations">
<node COLOR="#ffff00" CREATED="1345138246839" ID="ID_707032426" MODIFIED="1347799323533" TEXT="numbers"/>
<node COLOR="#ffff00" CREATED="1345138252637" ID="ID_1719638707" MODIFIED="1347799323533" TEXT="letters"/>
<node COLOR="#ffff00" CREATED="1345138258037" ID="ID_1239618923" MODIFIED="1347799323532" TEXT="rests"/>
<node COLOR="#ffff00" CREATED="1344865947030" ID="ID_1687854572" MODIFIED="1347799323532" TEXT="dots"/>
<node COLOR="#ffff00" CREATED="1344865948478" ID="ID_308839334" MODIFIED="1347799323532" TEXT="ties"/>
</node>
<node COLOR="#ffff00" CREATED="1344865952126" ID="ID_1841010506" MODIFIED="1347799323532" TEXT="tuplets">
<node COLOR="#ffff00" CREATED="1344865962033" ID="ID_1397017076" MODIFIED="1347799323532" TEXT="rhythm values"/>
<node COLOR="#ffff00" CREATED="1344865967769" ID="ID_1835112518" MODIFIED="1347799323532" TEXT="brackets"/>
</node>
<node COLOR="#ffff00" CREATED="1344865983528" ID="ID_857714623" MODIFIED="1347799323532" TEXT="beams"/>
<node COLOR="#ffff00" CREATED="1345139765663" ID="ID_1645654374" MODIFIED="1347799323532" TEXT="example">
<arrowlink DESTINATION="ID_1645654374" ENDARROW="Default" ENDINCLINATION="0;0;" ID="Arrow_ID_1894362021" STARTARROW="None" STARTINCLINATION="0;0;"/>
</node>
</node>
<node COLOR="#ffff00" CREATED="1344866240679" FOLDED="true" ID="ID_712010464" MODIFIED="1349124606958" TEXT="06 - rthm-seq object">
<node COLOR="#ffff00" CREATED="1345207707309" ID="ID_244062981" MODIFIED="1347888964926" TEXT="general">
<node COLOR="#ffff00" CREATED="1344866297625" ID="ID_1560604153" MODIFIED="1347888964926" TEXT="one or more measures"/>
<node COLOR="#ffff00" CREATED="1344866303080" ID="ID_1302248193" MODIFIED="1347888964926" TEXT="different time signatures"/>
<node COLOR="#ffff00" CREATED="1344866376925" ID="ID_1956548017" MODIFIED="1347888964926" TEXT="rthm-seq-map rthm-seqs must all have same time-sig/structure"/>
</node>
<node COLOR="#ffff00" CREATED="1344866247316" ID="ID_445522708" MODIFIED="1347888964926" TEXT="pitch-seq-palette">
<node COLOR="#ffff00" CREATED="1344866330618" ID="ID_43020693" MODIFIED="1347888964926" TEXT="pitch curves in general"/>
<node COLOR="#ffff00" CREATED="1344867727721" ID="ID_41769752" MODIFIED="1347888964926" TEXT="multiple pitch-curves in one pitch-seq-palette"/>
</node>
<node COLOR="#ffff00" CREATED="1344866272057" ID="ID_1036612445" MODIFIED="1347888964925" TEXT="marks">
<node COLOR="#ffff00" CREATED="1344866285527" ID="ID_1691604686" MODIFIED="1347888964925" TEXT="various marks">
<node COLOR="#ffff00" CREATED="1345209047905" ID="ID_945464999" MODIFIED="1347888964925" TEXT="staccato, accent"/>
<node COLOR="#ffff00" CREATED="1344866345498" ID="ID_1214676078" MODIFIED="1347888964925" TEXT="slurs, phrases"/>
<node COLOR="#ffff00" CREATED="1345210193807" ID="ID_196252475" MODIFIED="1347888964925" TEXT="cresc, dim"/>
</node>
</node>
</node>
<node COLOR="#ffff00" CREATED="1344865595581" FOLDED="true" ID="ID_1417111251" MODIFIED="1349124608490" TEXT="07 - Other core features">
<node COLOR="#ffff00" CREATED="1345291373226" ID="ID_684645769" MODIFIED="1348060298736" TEXT="layout">
<node COLOR="#ffff00" CREATED="1344865636508" ID="ID_636984892" MODIFIED="1348060298736" TEXT="title"/>
<node COLOR="#ffff00" CREATED="1344865752708" ID="ID_773183327" MODIFIED="1348060298735" TEXT="staff-groupings"/>
<node COLOR="#ffff00" CREATED="1344865759461" ID="ID_996672320" MODIFIED="1348060298735" TEXT="tempo-map"/>
</node>
<node COLOR="#ffff00" CREATED="1344865862828" ID="ID_1576553019" MODIFIED="1348060298735" TEXT="multiple sets in set-palette"/>
<node COLOR="#ffff00" CREATED="1344865896008" ID="ID_1016751039" MODIFIED="1348060298734" TEXT="multiple sections in set-map and rthm-seq-map"/>
<node COLOR="#ffff00" CREATED="1345291349404" ID="ID_1871564984" MODIFIED="1348060298734" TEXT="output">
<node COLOR="#ffff00" CREATED="1344866425409" ID="ID_951048076" MODIFIED="1348060298734" TEXT="specifying output file names"/>
<node COLOR="#ffff00" CREATED="1344866446571" ID="ID_1054288037" MODIFIED="1348060298734" TEXT="loading file at prompt to evaluate and produce output"/>
</node>
</node>
<node COLOR="#ffff00" CREATED="1344866211966" FOLDED="true" ID="ID_1692065721" MODIFIED="1349124609099" TEXT="08 - Set-limits-">
<node COLOR="#ffff00" CREATED="1344867394182" ID="ID_535449762" MODIFIED="1348060310113" TEXT="individual instruments"/>
<node COLOR="#ffff00" CREATED="1344867399126" ID="ID_823383563" MODIFIED="1348060310112" TEXT="&apos;all&apos; = tessitura shaping"/>
</node>
<node COLOR="#ffff00" CREATED="1345137728128" FOLDED="true" ID="ID_1239865673" MODIFIED="1349124610326" TEXT="09 - Chords">
<node COLOR="#ffff00" CREATED="1345293934647" ID="ID_1562277571" MODIFIED="1348080029810" TEXT="using parentheses in psp"/>
<node COLOR="#ffff00" CREATED="1345293960509" ID="ID_780082803" MODIFIED="1348080029810" TEXT="predefined chord functions">
<node COLOR="#ffff00" CREATED="1345293973592" ID="ID_1437636581" MODIFIED="1348080029810" TEXT="default"/>
<node COLOR="#ffff00" CREATED="1345293981424" ID="ID_1179091573" MODIFIED="1348080029809" TEXT="chord-fun1"/>
<node COLOR="#ffff00" CREATED="1345293984233" ID="ID_444975615" MODIFIED="1348080029809" TEXT="chord-fun2"/>
<node COLOR="#ffff00" CREATED="1345296991115" ID="ID_1083013025" MODIFIED="1348080029809" TEXT="instrument-specific">
<node COLOR="#ffff00" CREATED="1345293976640" ID="ID_1911141028" MODIFIED="1348080029809" TEXT="piano-chord-fun"/>
<node COLOR="#ffff00" CREATED="1345296997267" ID="ID_643657420" MODIFIED="1348080029809" TEXT="string functions"/>
<node COLOR="#ffff00" CREATED="1345297001354" ID="ID_1879932384" MODIFIED="1348080029809" TEXT="guitar function"/>
</node>
</node>
<node COLOR="#ffff00" CREATED="1345293944840" ID="ID_146998728" MODIFIED="1348080029809" TEXT="assigning chord function to instrument object"/>
<node COLOR="#ffff00" CREATED="1345293990850" ID="ID_995319591" MODIFIED="1348080029809" TEXT="see documentation on chords for how to make your own"/>
</node>
<node COLOR="#ffff00" CREATED="1344867409046" FOLDED="true" ID="ID_583904865" MODIFIED="1349124612358" TEXT="10 - Fibonacci transitions">
<node COLOR="#ffff00" CREATED="1344867449584" ID="ID_1595192064" MODIFIED="1348652904000" TEXT="what it does"/>
<node COLOR="#ffff00" CREATED="1344867442672" ID="ID_658680970" MODIFIED="1348652904000" TEXT="fibonacci-transition"/>
<node COLOR="#ffff00" CREATED="1344867456504" ID="ID_1767777274" MODIFIED="1348652904000" TEXT="fibonacci-transitions"/>
<node COLOR="#ffff00" CREATED="1344867484762" ID="ID_418746300" MODIFIED="1348652904000" TEXT="remix-in"/>
</node>
<node COLOR="#ffff00" CREATED="1344868004916" FOLDED="true" ID="ID_1372358667" MODIFIED="1349124612911" TEXT="11 - sc and clm 1">
<node COLOR="#ffff00" CREATED="1344868020422" ID="ID_852273766" MODIFIED="1348675605818" TEXT="what it does"/>
<node COLOR="#ffff00" CREATED="1344868026636" ID="ID_882176598" MODIFIED="1348675605818" TEXT="setting output directory"/>
<node COLOR="#ffff00" CREATED="1344868031284" ID="ID_1662878055" MODIFIED="1348675605817" TEXT="sndfile-palette"/>
<node COLOR="#ffff00" CREATED="1344868036019" ID="ID_964333183" MODIFIED="1348675605817" TEXT="groups"/>
<node COLOR="#ffff00" CREATED="1344868044288" ID="ID_1002909179" MODIFIED="1348675605817" TEXT="simple call to clm-play"/>
</node>
<node COLOR="#ffff00" CREATED="1344868154375" FOLDED="true" ID="ID_223196241" MODIFIED="1349124614239" TEXT="12 - sc and clm 2">
<node COLOR="#ffff00" CREATED="1344868064097" ID="ID_1287297057" MODIFIED="1348838851095" TEXT=":inc-start"/>
<node COLOR="#ffff00" CREATED="1344868079728" ID="ID_627520274" MODIFIED="1348838851095" TEXT=":duration, :start, :end"/>
<node COLOR="#ffff00" CREATED="1344868112389" ID="ID_1726033551" MODIFIED="1348838851095" TEXT=":frequency and :pitch-synchronous"/>
<node COLOR="#ffff00" CREATED="1344868213525" ID="ID_1118118732" MODIFIED="1348838851095" TEXT=":rev-amt and :src-width"/>
<node COLOR="#ffff00" CREATED="1344868136456" ID="ID_935872576" MODIFIED="1348838851095" TEXT="fibonacci-transitioning between two groups"/>
</node>
<node COLOR="#ffff00" CREATED="1344868250820" FOLDED="true" ID="ID_943059531" MODIFIED="1349124615046" TEXT="13 - sc and clm 3">
<node COLOR="#ffff00" CREATED="1344868256683" ID="ID_1762644043" MODIFIED="1349090000915" TEXT="output format arguments">
<node COLOR="#ffff00" CREATED="1344868263796" ID="ID_1179256541" MODIFIED="1349090000915" TEXT="channels"/>
<node COLOR="#ffff00" CREATED="1344868268107" ID="ID_7047801" MODIFIED="1349090000914" TEXT="srate"/>
<node COLOR="#ffff00" CREATED="1344868284825" ID="ID_157971677" MODIFIED="1349090000914" TEXT="header-type"/>
<node COLOR="#ffff00" CREATED="1344868290378" ID="ID_1431554160" MODIFIED="1349090000914" TEXT="data-format"/>
<node COLOR="#ffff00" CREATED="1344868296833" ID="ID_905643559" MODIFIED="1349090000914" TEXT="sndfile-extension"/>
</node>
</node>
<node COLOR="#ffff00" CREATED="1344868309205" FOLDED="true" ID="ID_1374388294" MODIFIED="1349187985274" TEXT="14 - sc and clm 4">
<node COLOR="#ffff00" CREATED="1344868313934" ID="ID_1841951605" MODIFIED="1349187974249" TEXT="independent tape parts">
<node COLOR="#ffff00" CREATED="1344868324749" ID="ID_1582006676" MODIFIED="1349187974248" TEXT="&quot;computer&quot; instrument in ensemble"/>
<node COLOR="#ffff00" CREATED="1344868337157" ID="ID_1563513971" MODIFIED="1349187974248" TEXT="computer player in rthm-seq-map"/>
<node COLOR="#ffff00" CREATED="1344868351543" ID="ID_1008009178" MODIFIED="1349187974248" TEXT="computer player in clm-play"/>
<node COLOR="#ffff00" CREATED="1344868358127" ID="ID_1244029459" MODIFIED="1349187974247" TEXT=":voices and :players arguments to exclude computer player from midi and score output"/>
</node>
</node>
<node COLOR="#ffff00" CREATED="1346322057042" ID="ID_1557866751" MODIFIED="1349277952175" TEXT="15 - What slipery chicken does"/>
<node COLOR="#ffff00" CREATED="1346335071595" ID="ID_21337141" MODIFIED="1349355858611" TEXT="16 - note selection algorithm"/>
<node COLOR="#ffff00" CREATED="1346333614625" ID="ID_954390880" MODIFIED="1349448965907" TEXT="17 - output"/>
<node COLOR="#ffff00" CREATED="1344867495186" FOLDED="true" ID="ID_25687912" MODIFIED="1354827746684" TEXT="18 - chop">
<font BOLD="true" NAME="Dialog" SIZE="11"/>
<node COLOR="#ffff00" CREATED="1344867519103" ID="ID_1360623534" MODIFIED="1354827743388" TEXT="what it does"/>
<node COLOR="#ffff00" CREATED="1344867504731" ID="ID_1951628526" MODIFIED="1354827743388" TEXT="chopping unit"/>
<node COLOR="#ffff00" CREATED="1344867510971" ID="ID_1721043729" MODIFIED="1354827743388" TEXT="chop points"/>
<node COLOR="#ffff00" CREATED="1344867553811" ID="ID_457063955" MODIFIED="1354827743388" TEXT="how it does it"/>
<node COLOR="#ffff00" CREATED="1344867569516" ID="ID_1472671788" MODIFIED="1354827743387" TEXT="three levels"/>
<node COLOR="#ffff00" CREATED="1344867576529" ID="ID_111724186" MODIFIED="1354827743387" TEXT="rthm-seq-palette chop">
<node COLOR="#ffff00" CREATED="1344867584257" ID="ID_1621518750" MODIFIED="1354827743387" TEXT="example"/>
<node COLOR="#ffff00" CREATED="1344867592687" ID="ID_1977868389" MODIFIED="1354827743387" TEXT="accessing rthm-seqs in a chopped palette"/>
</node>
</node>
<node COLOR="#ffff00" CREATED="1344867640206" FOLDED="true" ID="ID_718656161" MODIFIED="1355350623484" TEXT="19 - Intraphrasal looping">
<node COLOR="#ffff00" CREATED="1344867692716" ID="ID_1631233694" MODIFIED="1355341296773" TEXT="rsp-orig"/>
<node COLOR="#ffff00" CREATED="1344867695963" ID="ID_1424201306" MODIFIED="1355341296773" TEXT="rsp-chopped"/>
<node COLOR="#ffff00" CREATED="1344867902900" ID="ID_1959261925" MODIFIED="1355341296773" TEXT="assembling the rsm from the rsp-chopped fragments">
<node COLOR="#ffff00" CREATED="1344867939875" ID="ID_1012945804" MODIFIED="1355341296773" TEXT="using fibonacci-transitions to collect rsp-chopped frags"/>
</node>
<node COLOR="#ffff00" CREATED="1344867608189" ID="ID_1922853367" MODIFIED="1355341296772" TEXT="re-bar"/>
</node>
<node COLOR="#ffff00" CREATED="1344881072850" FOLDED="true" ID="ID_279362906" MODIFIED="1355528969418" TEXT="20 - l-systems">
<node COLOR="#ffff00" CREATED="1344881096852" ID="ID_482867439" MODIFIED="1355450713159" TEXT="basics">
<node COLOR="#ffff00" CREATED="1344881098270" ID="ID_920909608" MODIFIED="1355450713160" TEXT="symbols"/>
<node COLOR="#ffff00" CREATED="1344881101523" ID="ID_1832160484" MODIFIED="1355450713160" TEXT="rules"/>
<node COLOR="#ffff00" CREATED="1344881103148" ID="ID_924052914" MODIFIED="1355450713159" TEXT="axiom"/>
</node>
<node COLOR="#ffff00" CREATED="1344881150195" ID="ID_1889110401" MODIFIED="1355450725483" TEXT="l-for-lookup object"/>
<node COLOR="#ffff00" CREATED="1344881161982" ID="ID_1279318697" MODIFIED="1355450725483" TEXT="get-l-sequence"/>
<node COLOR="#ffff00" CREATED="1344881167510" ID="ID_1409887871" MODIFIED="1355450725483" TEXT="do-simple-lookup"/>
<node COLOR="#ffff00" CREATED="1344881173422" ID="ID_1341346969" MODIFIED="1355528966557" TEXT="do-lookup">
<node COLOR="#ffff00" CREATED="1344881178061" ID="ID_1017601381" MODIFIED="1355528966557" TEXT="fib trans"/>
</node>
<node COLOR="#ffff00" CREATED="1344881190741" ID="ID_1248019153" MODIFIED="1355528966557" TEXT="simple example with mini"/>
</node>
<node COLOR="#ffff33" CREATED="1344880562624" FOLDED="true" ID="ID_1377455075" MODIFIED="1355867820467" TEXT="21 - post-gen editing">
<node COLOR="#ffff33" CREATED="1344880590828" ID="ID_1891780132" MODIFIED="1355867819023" TEXT="events v notes"/>
<node COLOR="#ffff33" CREATED="1344880608758" ID="ID_1206366223" MODIFIED="1355867819023" TEXT="basic usage">
<node COLOR="#ffff33" CREATED="1344880622438" ID="ID_1964362620" MODIFIED="1355867819022" TEXT="sc object"/>
<node COLOR="#ffff33" CREATED="1344880611096" ID="ID_543480719" MODIFIED="1355867819022" TEXT="bar-number"/>
<node COLOR="#ffff33" CREATED="1344880616598" ID="ID_603208587" MODIFIED="1355867819022" TEXT="player"/>
<node COLOR="#ffff33" CREATED="1344880630671" ID="ID_1597603137" MODIFIED="1355867819022" TEXT="event- or note-number"/>
<node COLOR="#ffff33" CREATED="1344880638095" ID="ID_1404288572" MODIFIED="1355867819022" TEXT="new value"/>
</node>
<node COLOR="#ffff33" CREATED="1344880647573" ID="ID_1557761225" MODIFIED="1355867819021" TEXT="examples">
<node COLOR="#ffff33" CREATED="1344880668545" ID="ID_1914416113" MODIFIED="1355867819021" TEXT="change-pitch"/>
<node COLOR="#ffff33" CREATED="1344880648996" ID="ID_1825859693" MODIFIED="1355867819021" TEXT="add-mark-to-note"/>
<node COLOR="#ffff33" CREATED="1344880674441" ID="ID_1899491586" MODIFIED="1355867819021" TEXT="rm-marks-from-note"/>
<node COLOR="#ffff33" CREATED="1344880696069" ID="ID_1438415590" MODIFIED="1355867819020" TEXT="tie"/>
<node COLOR="#ffff33" CREATED="1344880703477" ID="ID_1612641872" MODIFIED="1355867819020" TEXT="double-events/move-events"/>
</node>
</node>
<node COLOR="#ffff00" CREATED="1344881207148" FOLDED="true" ID="ID_1901094604" MODIFIED="1356060491736" TEXT="22 - rthm-chains">
<node COLOR="#ffff00" CREATED="1344881228463" ID="ID_1029160115" MODIFIED="1356060486028" TEXT="what it does">
<node COLOR="#ffff00" CREATED="1344881245790" ID="ID_217485605" MODIFIED="1356060486027" TEXT="Algorithmic generation of 2-voice rthm-seq-palette and rthm-seq-map."/>
<node COLOR="#ffff00" CREATED="1344881269344" ID="ID_1315727590" MODIFIED="1356060486027" TEXT="generated from ">
<node COLOR="#ffff00" CREATED="1344881276480" ID="ID_49979105" MODIFIED="1356060486027" TEXT="shorter 1-beat frags"/>
<node COLOR="#ffff00" CREATED="1344881281985" ID="ID_1875859686" MODIFIED="1356060486027" TEXT="longer 2- or 3-beat frags"/>
</node>
</node>
<node COLOR="#ffff00" CREATED="1344881219351" ID="ID_918601054" MODIFIED="1356060486027" TEXT="procession"/>
<node COLOR="#ffff00" CREATED="1344881314145" ID="ID_1278590909" MODIFIED="1356060486027" TEXT="make-rthm-chain"/>
<node COLOR="#ffff00" CREATED="1344881427874" ID="ID_1888114642" MODIFIED="1356060486026" TEXT="add voice"/>
<node COLOR="#ffff00" CREATED="1344881375901" ID="ID_1286156947" MODIFIED="1356060486026" TEXT="some helpful post-gen methods">
<node COLOR="#ffff00" CREATED="1344881346046" ID="ID_342150688" MODIFIED="1356060486026" TEXT="consolidate-notes"/>
<node COLOR="#ffff00" CREATED="1344881352740" ID="ID_929240879" MODIFIED="1356060486026" TEXT="consolidate-rests-max"/>
<node COLOR="#ffff00" CREATED="1344881394781" ID="ID_1305035386" MODIFIED="1356060486026" TEXT="map-over-bars"/>
<node COLOR="#ffff00" CREATED="1344881368885" ID="ID_709846399" MODIFIED="1356060486026" TEXT="tie-over-rests"/>
<node COLOR="#ffff00" CREATED="1344881389125" ID="ID_1622258614" MODIFIED="1356060486025" TEXT="handle-ties"/>
</node>
<node COLOR="#ffff00" CREATED="1349878828364" ID="ID_456077079" MODIFIED="1356060486025" TEXT="might not get beyond this one"/>
</node>
<node COLOR="#ffff00" CREATED="1344880962828" FOLDED="true" ID="ID_931426660" MODIFIED="1356206464317" TEXT="23 - permutations">
<node COLOR="#ffff00" CREATED="1344880996762" ID="ID_811368570" MODIFIED="1356206460233" TEXT="permutations"/>
<node COLOR="#ffff00" CREATED="1344881005922" ID="ID_468401809" MODIFIED="1356206460233" TEXT="inefficient-permutations"/>
<node COLOR="#ffff00" CREATED="1344881019089" ID="ID_952145950" MODIFIED="1356206460233" TEXT="inefficiently-permutate"/>
<node COLOR="#ffff00" CREATED="1344881026608" ID="ID_197785136" MODIFIED="1356206460233" TEXT="shuffle"/>
<node COLOR="#ffff00" CREATED="1344881037362" ID="ID_179941490" MODIFIED="1356206460232" TEXT="move-repeats"/>
<node COLOR="#ffff00" CREATED="1344881043083" ID="ID_1713685744" MODIFIED="1356206460232" TEXT="example with a mini">
<node COLOR="#ffff00" CREATED="1344881048436" ID="ID_253530537" MODIFIED="1356206460232" TEXT="use one of the examples from workshop"/>
</node>
</node>
<node COLOR="#ffff00" CREATED="1344880732931" FOLDED="true" ID="ID_988596013" MODIFIED="1356224130951" TEXT="24 - score layout 1">
<node COLOR="#ffff00" CREATED="1344880766391" ID="ID_550971803" MODIFIED="1356224127667" TEXT="header">
<node COLOR="#ffff00" CREATED="1345477826902" ID="ID_1774715039" MODIFIED="1356224127667" TEXT="title"/>
<node COLOR="#ffff00" CREATED="1345477829685" ID="ID_1514979558" MODIFIED="1356224127667" TEXT="composer"/>
</node>
<node COLOR="#ffff00" CREATED="1344880768927" ID="ID_1744034437" MODIFIED="1356224127667" TEXT="score order"/>
<node COLOR="#ffff00" CREATED="1344880788359" ID="ID_1789379341" MODIFIED="1356224127667" TEXT="staff grouping"/>
<node COLOR="#ffff00" CREATED="1344880840019" ID="ID_1192693260" MODIFIED="1356224127666" TEXT="rehearsal letters"/>
</node>
<node COLOR="#ffff00" CREATED="1344880825046" FOLDED="true" ID="ID_1722438408" MODIFIED="1356232260977" TEXT="25 - score layout 2">
<node COLOR="#ffff00" CREATED="1344880828702" ID="ID_1019365035" MODIFIED="1356232248005" TEXT="bar line types"/>
<node COLOR="#ffff00" CREATED="1344880861097" ID="ID_14130481" MODIFIED="1356232248005" TEXT="clefs">
<node COLOR="#ffff00" CREATED="1344880875695" ID="ID_941489717" MODIFIED="1356232248005" TEXT="disable auto-clefs first"/>
<node COLOR="#ffff00" CREATED="1344880893557" ID="ID_381925327" MODIFIED="1356232248004" TEXT="add-clef/delete-clefs"/>
</node>
<node COLOR="#ffff00" CREATED="1344880919535" ID="ID_1111039459" MODIFIED="1356232248004" TEXT="scores in c"/>
<node COLOR="#ffff00" CREATED="1344880935395" ID="ID_679681324" MODIFIED="1356232248004" TEXT="parts"/>
</node>
</node>
</node>
</node>
<node COLOR="#ffffff" CREATED="1342208225768" ID="ID_535070653" MODIFIED="1349124543355" POSITION="left" TEXT="september">
<node COLOR="#ffff00" CREATED="1341491446242" ID="ID_274702155" MODIFIED="1356232269890" TEXT="compositions">
<node COLOR="#ffff00" CREATED="1342207721530" ID="ID_1069394501" MODIFIED="1356232258946" TEXT="A rthm-chains piece"/>
</node>
<node COLOR="#ffffff" CREATED="1338981748877" ID="ID_1519032688" MODIFIED="1349124548830" TEXT="manual">
<node COLOR="#ffffff" CREATED="1341491502269" ID="ID_1166044590" MODIFIED="1351274278371" TEXT="pages">
<node COLOR="#ffff00" CREATED="1338981719342" ID="ID_715881251" MODIFIED="1343999077497" TEXT="Featured Algorithms: Lindenmayer"/>
<node COLOR="#ffff00" CREATED="1341491436802" ID="ID_317408462" MODIFIED="1344506629955" TEXT="Demo Compositions/Tutorials: SC-CLM Tutorial Piece"/>
<node COLOR="#ffff00" CREATED="1345569697921" ID="ID_675701242" MODIFIED="1349355265800" TEXT="second-law clm extension"/>
<node COLOR="#ffff00" CREATED="1338981739814" ID="ID_766608134" MODIFIED="1349800487547" TEXT="Rhythm Chains"/>
<node COLOR="#ffff00" CREATED="1342184195174" ID="ID_1186199410" MODIFIED="1354652141936" TEXT="Rhythm Chains Tutorial Piece">
<node COLOR="#ffff00" CREATED="1349878554953" ID="ID_1219779650" MODIFIED="1354652141937" TEXT="from workshop example"/>
</node>
<node COLOR="#ffff00" CREATED="1341491994317" ID="ID_1530312761" MODIFIED="1353187566226" TEXT="envelopes"/>
<node COLOR="#ffff00" CREATED="1341491428058" ID="ID_499990897" MODIFIED="1353451785237" TEXT="Permutations"/>
<node COLOR="#ffff00" CREATED="1341492094204" ID="ID_245381740" MODIFIED="1353609443150" TEXT="enharmonics">
<node COLOR="#ffff00" CREATED="1348853678901" ID="ID_1860616400" MODIFIED="1353609443149" TEXT="2nd argument to respell-notes">
<richcontent TYPE="NOTE"><html>
  <head>
    
  </head>
  <body>
    <p>
      (respell-notes +coming-rthm-chain+
    </p>
    <p>
      &#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;'((cello (117 1) (118 2) (135 3) (546 1) (546 2) (137 2) (428 3)
    </p>
    <p>
      &#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;(223 5) (591 (1 2)) (596 (2 2)) (538 4) (582 2) (625 (2 1))
    </p>
    <p>
      &#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;(22 1) (24 1) (31 4) (34 4) (37 1)
    </p>
    <p>
      &#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;(214 3) (596 (1 2)) (596 (4 2)) (625 (3 1)))
    </p>
    <p>
      &#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;(violin (539 5) (154 1) (154 2) (154 3) (155 1) (155 2)
    </p>
    <p>
      &#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;(111 1) (628 2) (629 1) (630 1) (631 1) (452 4) (452 5)
    </p>
    <p>
      &#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;(453 1) (453 2) (454 1))
    </p>
    <p>
      &#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;(marimba (41 1) (42 1) (43 1) (44 1) (45 1) (438 1) (447 1)
    </p>
    <p>
      &#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;(521 4) (521 5) (594 2) (595 1) (600 2) (28 1) (28 2) (28 3)
    </p>
    <p>
      &#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;(572 1) (572 2) (572 (3 1)) (572 (3 2)) (204 2) (211 4)
    </p>
  </body>
</html></richcontent>
<node COLOR="#ffff00" CREATED="1348853757166" ID="ID_1054295117" MODIFIED="1353609443149" TEXT="would be useful to add to page that talks about calling respell-notes explicitly">
<node COLOR="#ffffff" CREATED="1348853833053" ID="ID_1736100762" MODIFIED="1349124520349" TEXT="or did we only write about auto-clefs? "/>
<node COLOR="#ffff00" CREATED="1348853860234" ID="ID_1735976932" MODIFIED="1353609449728" TEXT="in any case, discussion of respell-notes would be useful"/>
</node>
<node COLOR="#ffffff" CREATED="1348853779299" ID="ID_714797717" MODIFIED="1349124520348" TEXT="or separate page and link to this from existing page"/>
</node>
</node>
<node COLOR="#ffff00" CREATED="1345568828947" ID="ID_487808139" MODIFIED="1353687872659" TEXT="add the workshop exercises to a new page">
<node COLOR="#ffff00" CREATED="1345568855918" ID="ID_223525327" MODIFIED="1353687877331" TEXT="link from a manual page to the exercises page if something appropriate exists"/>
<node COLOR="#ffffff" CREATED="1345568877491" ID="ID_1945672114" MODIFIED="1349124525513" TEXT="consider an extension to a mini or two per page to allow the reader to test their skills"/>
<node COLOR="#ffffff" CREATED="1345568848203" ID="ID_1996786835" MODIFIED="1349124525513" TEXT="will need to provide solutions"/>
</node>
<node COLOR="#ffffff" CREATED="1341492131896" ID="ID_898645977" MODIFIED="1349124499815" TEXT="algorithmic generation examples - sets, rthm-seqs, maps, note-heads/marks">
<node COLOR="#ffffff" CREATED="1341492218042" ID="ID_1694646315" MODIFIED="1349124530216" TEXT="permutations.lsp functions"/>
<node COLOR="#ffffff" CREATED="1341492228346" ID="ID_1766572628" MODIFIED="1349124530216" TEXT="self-designed"/>
</node>
<node COLOR="#ffffff" CREATED="1341491432698" ID="ID_188518795" MODIFIED="1349124535623" TEXT="Popcorn"/>
</node>
<node COLOR="#ffffff" CREATED="1341491771624" ID="ID_540871770" MODIFIED="1349124555390" TEXT="specifics">
<node COLOR="#ffff00" CREATED="1341491774243" ID="ID_330163467" MODIFIED="1353692770225" TEXT="instrument-pal">
<node COLOR="#ffff00" CREATED="1341491798804" ID="ID_1903737063" MODIFIED="1353692766985" TEXT="update ug and rbdc to state default"/>
<node COLOR="#ffffff" CREATED="1341491814840" ID="ID_820469466" MODIFIED="1349124555390" TEXT="remove from examples"/>
</node>
<node COLOR="#ffffff" CREATED="1341492269358" ID="ID_107047409" MODIFIED="1349124555390" TEXT="score layout">
<node COLOR="#ffffff" CREATED="1341492273417" ID="ID_1231066199" MODIFIED="1349124555390" TEXT="bar numbers"/>
<node COLOR="#ffffff" CREATED="1341492563094" ID="ID_175921347" MODIFIED="1349124555390" TEXT="stemlets"/>
</node>
</node>
<node COLOR="#ffffff" CREATED="1341492466556" ID="ID_1293442811" MODIFIED="1349124563620" TEXT="add a sentence to every object in the user guide that it can be passed an objet (as a variable) within the make-slippery-chicken function (and defined elsewhere, for example)">
<node COLOR="#ffffff" CREATED="1348854135017" ID="ID_160633451" MODIFIED="1349124563624" TEXT="actually, just describe the use of the global and/or local variable in core usage and second law"/>
</node>
<node COLOR="#ffffff" CREATED="1341491866550" ID="ID_532774771" MODIFIED="1349124571479" TEXT="finish script for automatic pdf generation">
<node COLOR="#ff0000" CREATED="1342207796456" ID="ID_1021541335" MODIFIED="1342207856370" TEXT="make PDF of manual look more fancy e.g.">
<node COLOR="#ff0000" CREATED="1342207812024" ID="ID_875194516" MODIFIED="1342207856370" TEXT="include graphic on title page"/>
<node COLOR="#ff0000" CREATED="1342207820261" ID="ID_1182003988" MODIFIED="1342207856370" TEXT="use \input to include files"/>
<node COLOR="#ff0000" CREATED="1342207831529" ID="ID_536979899" MODIFIED="1342207856370" TEXT="change text width/height to get more on one page"/>
</node>
<node COLOR="#ffffff" CREATED="1353691807190" ID="ID_1825023646" MODIFIED="1353691844176" TEXT="remember to add all html files to sc/doc/manual/sc-users-guide.tex">
<richcontent TYPE="NOTE"><html>
  <head>
    
  </head>
  <body>
    <p>
      &#207;
    </p>
  </body>
</html></richcontent>
</node>
</node>
<node COLOR="#ffffff" CREATED="1341491883606" ID="ID_1798968927" MODIFIED="1349124571480" TEXT="add rbdc hyperlinks to all methods mentioned in block text"/>
<node COLOR="#ffff00" CREATED="1341492408287" ID="ID_1077966816" MODIFIED="1353548630426" TEXT="change to note-heads (with hyphen)"/>
<node COLOR="#ffff00" CREATED="1341492434582" ID="ID_146801189" MODIFIED="1353549041627" TEXT="remove hyphen from &lt;em&gt;slippery-chicken&lt;/em&gt;"/>
<node COLOR="#ffff00" CREATED="1341492451837" ID="ID_1103189018" MODIFIED="1353549455430" TEXT="remove &lt;em&gt; from all &lt;code&gt; items"/>
<node COLOR="#ff0000" CREATED="1342207866658" ID="ID_58879471" MODIFIED="1342207896289" TEXT="plus any other items found in sc-manual.mm"/>
</node>
</node>
<node COLOR="#ffffff" CREATED="1342208229783" ID="ID_1473577811" MODIFIED="1349124582857" POSITION="left" TEXT="october">
<node COLOR="#ffffff" CREATED="1341491553179" ID="ID_772881101" MODIFIED="1349124582861" TEXT="website format">
<node COLOR="#ffff00" CREATED="1341491557286" ID="ID_1574137459" MODIFIED="1353689032732" TEXT="modify source code block width">
<node COLOR="#ffff00" CREATED="1341491568093" ID="ID_970323307" MODIFIED="1353689032732" TEXT="currently cutting off the end of line occasionally"/>
</node>
<node COLOR="#ffff00" CREATED="1341491588354" ID="ID_1556028536" MODIFIED="1353689038393" TEXT="review css for space between certain blocks">
<node COLOR="#ffff00" CREATED="1341491607935" ID="ID_1235337524" MODIFIED="1353689038393" TEXT="e.g. close link"/>
</node>
<node COLOR="#ffff00" CREATED="1341491632664" ID="ID_347147413" MODIFIED="1353689131491" TEXT="review robodoc layout to ensure nice spacing"/>
<node COLOR="#ff0000" CREATED="1341492530454" ID="ID_1518196544" MODIFIED="1353553420456" TEXT="add sc-logo as favicon">
<node COLOR="#ff0000" CREATED="1353553382518" ID="ID_1161619840" MODIFIED="1353553420456" TEXT="not going to do as inconsistent among browsers"/>
</node>
<node COLOR="#ffffff" CREATED="1341492900310" ID="ID_749763601" MODIFIED="1349124582860" TEXT="validate all web pages"/>
</node>
<node COLOR="#ffffff" CREATED="1341491931524" ID="ID_114042220" MODIFIED="1349124582860" TEXT="platform testing">
<node COLOR="#ffffff" CREATED="1341491936722" ID="ID_975337291" MODIFIED="1349124582860" TEXT="test on 32-bit windows"/>
<node COLOR="#ffffff" CREATED="1341491944924" ID="ID_1902468657" MODIFIED="1349124582859" TEXT="test with other linuxes">
<node COLOR="#ffffff" CREATED="1341491961348" ID="ID_1572855183" MODIFIED="1349124582859" TEXT="ubuntu"/>
<node COLOR="#ffffff" CREATED="1341492383904" ID="ID_66636433" MODIFIED="1349124582859" TEXT="fedora 17"/>
</node>
<node COLOR="#ffffff" CREATED="1341491953469" ID="ID_1051667803" MODIFIED="1349124582859" TEXT="test with other lisps">
<node COLOR="#ffffff" CREATED="1341491970788" ID="ID_452445866" MODIFIED="1349124582859" TEXT="cmucl"/>
<node COLOR="#ffffff" CREATED="1341491974204" ID="ID_1920243348" MODIFIED="1349124582859" TEXT="clisp"/>
</node>
</node>
<node COLOR="#ffffff" CREATED="1341492611647" ID="ID_729594503" MODIFIED="1349124582859" TEXT="program new methods">
<node COLOR="#ffffff" CREATED="1341492622572" ID="ID_1282106375" MODIFIED="1349124582858" TEXT="automatically replace rhythms of a bar to divide at beat and consolidate">
<node COLOR="#ffffff" CREATED="1341492715140" ID="ID_51349756" MODIFIED="1349124582858" TEXT="most of this already done"/>
<node COLOR="#ffffff" CREATED="1341492723196" ID="ID_1220985686" MODIFIED="1349124582858" TEXT="review why it&apos;s not working with anything but 4/4"/>
</node>
<node COLOR="#ffffff" CREATED="1341492656800" ID="ID_1270672777" MODIFIED="1349124582858" TEXT="automatically transpose key signatures"/>
</node>
<node COLOR="#ffffff" CREATED="1342179582152" ID="ID_616390263" MODIFIED="1349124582858" TEXT="add more instruments to standard palette"/>
<node COLOR="#ffffff" CREATED="1341491446242" ID="ID_1324876914" MODIFIED="1349124582858" TEXT="compositions">
<node COLOR="#ffffff" CREATED="1341491457241" ID="ID_282404719" MODIFIED="1349124582858" TEXT="Longer, more complex avant garde piece">
<node COLOR="#ffffff" CREATED="1341491480541" ID="ID_619047481" MODIFIED="1349124582857" TEXT="more user-defined functions, loops"/>
<node COLOR="#ffffff" CREATED="1342208809555" ID="ID_1624202331" MODIFIED="1349124582857" TEXT="demonstration post-generation editing"/>
</node>
</node>
</node>
</node>
</map>
